pub struct StoredHsDescMeta {
blinded_id: HsBlindId,
idx_info: IndexInfo,
}Expand description
Metadata about an onion service descriptor, as stored at an HsDir.
This object is parsed from the outermost document of an onion service descriptor, and used on the HsDir to maintain its index. It does not include the inner documents’ information about introduction points, since the HsDir cannot decrypt those without knowing the onion service’s un-blinded identity.
The HsDir caches this value, along with the original text of the descriptor.
Fields
blinded_id: HsBlindIdThe blinded onion identity for this descriptor. (This is the only identity that the HsDir knows.)
idx_info: IndexInfoInformation about the expiration and revision counter for this descriptor.
Implementations
Sourceimpl StoredHsDescMeta
impl StoredHsDescMeta
Sourcepub fn parse(input: &str) -> Result<UncheckedStoredHsDescMeta>
pub fn parse(input: &str) -> Result<UncheckedStoredHsDescMeta>
Parse the outermost layer of the descriptor in input, and return the
resulting metadata (if possible).
Sourceimpl StoredHsDescMeta
impl StoredHsDescMeta
Sourcefn from_outer_doc(outer: &HsDescOuter) -> Self
fn from_outer_doc(outer: &HsDescOuter) -> Self
Create a new StoredHsDescMeta from the outer part of an onion service descriptor.